import { GraphQLClient } from 'graphql-request';

//const gql = new GraphQLClient('/graphql', {headers: {Authorization: 'Bearer ' + ... }})

const getGQL = (url='http://shop-roles.asmer.fs.a-level.com.ua/graphql', 
    getHeaders=(()=>localStorage.authToken ? {Authorization: `Bearer ${localStorage.authToken}`} : 
                                                     {})) =>
(query='', variables={}) =>
    fetch(url, {
        method: 'POST',
        headers:{
             'Accept': 'application/json',
              'Content-Type': 'application/json',
             ...getHeaders()
            },
        body: JSON.stringify({query, variables})
    }).then(res => res.json()).then(data => { 
        if (data.errors){
            throw new Error(JSON.stringify(data.errors, null, 4))
        }
        const firstKey = Object.keys(data.data)[0]
        return firstKey ? data.data[firstKey] : data.data
    })

const gql = getGQL()

export const actionSearch = text => ({type: 'SEARCH', text})
export const actionSearchResult = payload => ({type: 'SEARCH_RESULT', payload})

export const actionPromise = (name, promise) => {
    const actionPending = () => ({type: 'PROMISE', name, status: 'PENDING', payload: null, error: null})
    const actionResolved = payload => ({type: 'PROMISE', name, status: 'RESOLVED', payload, error: null})
    const actionRejected = error => ({type: 'PROMISE', name, status: 'REJECTED', payload:null, error})


    return async dispatch => {
        dispatch(actionPending())
        let payload
        try {
            payload = await promise
            dispatch(actionResolved(payload))
        }
        catch (e){
            dispatch(actionRejected(e))
        }
        return payload;
    }
}

export const actionOrders = () => {
    return actionPromise('orders', gql( `query orders($allQuery:String){
                              OrderFind(query:$allQuery){
                                _id total orderGoods{
                                  total count good{ name }
                                }
                              }
                            }`, {allQuery: JSON.stringify([{}])}))
}


export const actionCategories = () => {
    return actionPromise('categories', gql(
            `query {
              CategoryFind(query:"[{\\"parent\\":null}]"){
                _id name
              }
        }
        `))
}


export const actionCategory = (_id) => {
    return actionPromise('category', gql(
                    `query cat($query:String){
                      CategoryFindOne(query:$query){
                        _id name goods{
                            _id name images{ url }
                        }
                      }
                    }`, {query: JSON.stringify([{_id}])}))
}


export const actionLogin = (login,password) => 
    async dispatch => {
        console.log(login, password)
        let result = await dispatch(actionPromise('login', gql(`query login($login: String!, $password: String!){
              login(username: $login, password: $password)
            }`, {login, password})))
        if (result){
            dispatch(actionAuthLogin(result.login))
        }
    }


export const actionAuthLogin = (jwt) => ({
    type: "LOGIN",
    jwt
})


export const actionAuthLogout = () => {
//    history.push('/')
    return {
        type: "LOGOUT",
    }
}
